# AccessRequests

Contains information about requests from a pending user or a user with at least one request The id of this object is the user's id. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithOnlyId**](MetadataWithOnlyId.md) |  | 
**status** | [**AccessRequestsStatus**](AccessRequestsStatus.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


